@@ -22,7 +22,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 '''
-import click, logging, time, yaml, json, platform, sys, os
+import click, logging, time, yaml, json, platform, sys, os, arrow
 from tenable.io import TenableIO
 from tenable.sc import TenableSC
 from .config import base_config
@@ -67,6 +67,12 @@ def cli(configfile, observed_since, setup_only=False, troubleshoot=False):
     config = dict_merge(base_config(), config_from_file)
     config['fields'] = config['fields'] + fields
 
+    if config['tenable'].get('tio_transform_tags'):
+        attr_cache = config['tenable'].get('tio_asset_attr_cache', list())
+        tag_attrs = config['tenable'].get('tio_transform_tags', list())
+        config['tenable']['tio_asset_attr_cache'] = attr_cache + tag_attrs
+
+
     # Get the logging definition and define any defaults as need be.
     log = config.get('log', {})
     log_lvls = {'debug': 10, 'info': 20, 'warn': 30, 'error': 40}
@@ -103,6 +109,13 @@ def cli(configfile, observed_since, setup_only=False, troubleshoot=False):
     # Initiate the Tenable.io API model, the Ingester model, and start the
     # ingestion and data transformation.
     if config['tenable'].get('platform') == 'tenable.io':
+        if not observed_since:
+            # if no since field is supplied, then look in the config file to see
+            # if an age was applied, if not, then use the default of 30 days.
+            observed_since = arrow.now()\
+                .shift(days=-config['tenable'].get('tio_age', 30))\
+                .floor('day').timestamp
+
         source = TenableIO(
             access_key=config['tenable'].get('access_key'),
             secret_key=config['tenable'].get('secret_key'),
